@@ -1,19 +1,18 @@
-# @(#)Ident: ExceptionClasses.pm 2013-08-28 20:32 pjf ;
+# @(#)Ident: ExceptionClasses.pm 2013-09-27 12:23 pjf ;
 
 package Unexpected::TraitFor::ExceptionClasses;
 
 use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.12.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Unexpected::Functions   qw( inflate_message );
 use Moo::Role;
 
-my $Root    = 'Unexpected';
-my $Classes = { $Root => {} };
+my $Root = 'Unexpected'; my $Classes = { $Root => {} };
 
 has 'class' => is => 'ro', isa => sub {
    ($_[ 0 ] and exists $Classes->{ $_[ 0 ] }) or die inflate_message
-      ( 'Exception class [_1] does not exist', $_[ 0 ] ) }, default => $Root;
+      ( 'Exception class "[_1]" does not exist', $_[ 0 ] ) }, default => $Root;
 
 sub has_exception {
    my ($self, @args) = @_; my $i = 0;
@@ -99,7 +98,7 @@ Unexpected::TraitFor::ExceptionClasses - Define an exception class hierarchy
 
 =head1 Version
 
-This documents version v0.12.$Rev: 1 $
+This documents version v0.13.$Rev: 1 $
 of L<Unexpected::TraitFor::ExceptionClasses>
 
 =head1 Description
